@@ -1,5 +1,5 @@
 """
-   Copyright 2019-2021 Boris Shminke
+   Copyright 2019-2022 Boris Shminke
 
    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
@@ -17,8 +17,5 @@ from neural_semigroups.associator_loss import AssociatorLoss
 from neural_semigroups.constant_baseline import ConstantBaseline
 from neural_semigroups.cyclic_group import CyclicGroup
 from neural_semigroups.denoising_autoencoder import MagmaDAE
-from neural_semigroups.mace4_semigroups_dataset import Mace4Semigroups
 from neural_semigroups.magma import Magma
 from neural_semigroups.precise_guess_loss import PreciseGuessLoss
-from neural_semigroups.semigroups_dataset import SemigroupsDataset
-from neural_semigroups.smallsemi_dataset import Smallsemi
